namespace TestThinkGeoOnLinux6
{
    using Microsoft.AspNetCore.Builder;
    using Microsoft.Extensions.DependencyInjection;
    using System;
    using System.IO;
    using System.Linq;
    using ThinkGeo.Core;

    public class Program
    {
        public static void Main(string[] args)
        {
            var message = "";

            File.WriteAllText("/app/Logs.txt", "Starting Container and Application.");

            var builder = WebApplication.CreateBuilder(args);

            // Add services to the container.
            builder.Services.AddControllers();
            // Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
            builder.Services.AddEndpointsApiExplorer();
            builder.Services.AddSwaggerGen();

            var app = builder.Build();

            File.WriteAllText("/app/Logs.txt", message);

            try
            {
                var doesFileExist = File.Exists("JasonMontana1.kml");
                message += "Does the File Exist? " + doesFileExist + ". ";

                var creationTime = File.GetCreationTime("JasonMontana1.kml");
                message += "When was the file created? " + creationTime.ToLongTimeString() + ". ";

                var kmlFeatureLayerSource = new GdalFeatureSource("JasonMontana1.kml", FileAccess.Read);
                kmlFeatureLayerSource.Open();

                var features = kmlFeatureLayerSource.GetAllFeatures(ReturningColumnsType.AllColumns);

                if (features.Any())
                {
                    message += "Success, found " + features.Count() + " feature(s)";
                }
                else
                {
                    message += "No features found.";
                }
            }
            catch (Exception ex)
            {
                message += ex.ToString();
                File.WriteAllText("/app/Logs.txt", message);
            }

            app.MapGet("/", () => message);

            // Configure the HTTP request pipeline.
            if (app.Environment.IsDevelopment())
            {
                app.UseSwagger();
                app.UseSwaggerUI();
            }

            app.UseHttpsRedirection();

            app.UseAuthorization();

            app.MapControllers();

            app.Run();
        }
    }
}
